==> oarepo_runtime-1.5.104.tar.gz: oarepo_runtime-1.5.104/oarepo_runtime/services/schema/rdm_ui.py <==
import marshmallow as ma
from oarepo_runtime.services.schema.marshmallow import DictOnlySchema

class RDMIdentifierWithSchemaUISchema(ma.Schema):
    scheme = ma.fields.String(
        required=True,
    )
    identifier = ma.fields.String(required=True)

class RDMAwardIdentifierUISchema(ma.Schema):
    identifier = ma.fields.String()

class RDMAwardSubjectUISchema(ma.Schema):
    _id = ma.fields.String(data_key="id")

    subject = ma.fields.String()

class RDMAwardOrganizationUISchema(ma.Schema):
    schema = ma.fields.String()

    _id = ma.fields.String(data_key="id")

    organization = ma.fields.String()

class RDMFunderVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma.fields.String(data_key="id", attribute="id")

    _version = ma.fields.String(data_key="@v", attribute="@v")

    name = VocabularyI18nStrUIField()

    identifier = ma.fields.Nested(RDMIdentifierWithSchemaUISchema())


class RDMRoleVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")

class RDMAwardVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = String(data_key="id", attribute="id")

    _version = String(data_key="@v", attribute="@v")

    title = VocabularyI18nStrUIField()

    number = ma.fields.String()

    identifier = ma.fields.List(ma.fields.Nested(RDMAwardIdentifierUISchema()))

    acronym = ma.fields.String()

    program = ma.fields.String()

    subjects = ma.fields.List(ma.fields.Nested(RDMAwardSubjectUISchema()))

    organizations = ma.fields.List(ma.fields.Nested(RDMAwardOrganizationUISchema()))


class RDMFundersUISchema(ma.Schema):
    """Funding ui schema."""
    class Meta:
        unknown = ma.RAISE

    funder = ma_fields.Nested(lambda: RDMFunderVocabularyUISchema())

    award = ma_fields.Nested(lambda: RDMAwardVocabularyUISchema())


class RDMPersonOrOrganizationUISchema(ma.Schema):
    class Meta:
        unknown = ma.INCLUDE

    name = ma.fields.String()

    type = ma.fields.String()

    given_name = ma.fields.String()

    family_name = ma.fields.String()

    identifiers = ma.fields.List(ma.fields.Nested(RDMIdentifierWithSchemaUISchema()))


class RDMAffiliationVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma.fields.String(data_key="id", attribute="id")

    _version = ma.fields.String(data_key="@v", attribute="@v")

    name = VocabularyI18nStrUIField()

class RDMCreatorsUISchema(ma.Schema):
    """Funding ui schema."""
    class Meta:
        unknown = ma.RAISE

    role = ma.fields.Nested(lambda: RDMRoleVocabularyUISchema())

    affiliations = ma.fields.List(ma_fields.Nested(lambda: RDMAffiliationVocabularyUISchema()))

    person_or_org = ma_fields.Nested(RDMPersonOrOrganizationUISchema())

==> oarepo_runtime-1.5.106.tar.gz: oarepo_runtime-1.5.106/oarepo_runtime/services/schema/rdm_ui.py <==
import marshmallow as ma
from oarepo_runtime.services.schema.marshmallow import DictOnlySchema
from oarepo_vocabularies.services.ui_schema import VocabularyI18nStrUIField

class RDMIdentifierWithSchemaUISchema(ma.Schema):
    scheme = ma.fields.String(
        required=True,
    )
    identifier = ma.fields.String(required=True)

class RDMAwardIdentifierUISchema(ma.Schema):
    identifier = ma.fields.String()

class RDMAwardSubjectUISchema(ma.Schema):
    _id = ma.fields.String(data_key="id")

    subject = ma.fields.String()

class RDMAwardOrganizationUISchema(ma.Schema):
    schema = ma.fields.String()

    _id = ma.fields.String(data_key="id")

    organization = ma.fields.String()

class RDMFunderVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma.fields.String(data_key="id", attribute="id")

    _version = ma.fields.String(data_key="@v", attribute="@v")

    name = VocabularyI18nStrUIField()

    identifier = ma.fields.Nested(RDMIdentifierWithSchemaUISchema())


class RDMRoleVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma.fields.String(data_key="id", attribute="id")

    _version = ma.fields.String(data_key="@v", attribute="@v")

class RDMAwardVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma.fields.String(data_key="id", attribute="id")

    _version = ma.fields.String(data_key="@v", attribute="@v")

    title = VocabularyI18nStrUIField()

    number = ma.fields.String()

    identifier = ma.fields.List(ma.fields.Nested(RDMAwardIdentifierUISchema()))

    acronym = ma.fields.String()

    program = ma.fields.String()

    subjects = ma.fields.List(ma.fields.Nested(RDMAwardSubjectUISchema()))

    organizations = ma.fields.List(ma.fields.Nested(RDMAwardOrganizationUISchema()))


class RDMFundersUISchema(ma.Schema):
    """Funding ui schema."""
    class Meta:
        unknown = ma.RAISE

    funder = ma.fields.Nested(lambda: RDMFunderVocabularyUISchema())

    award = ma.fields.Nested(lambda: RDMAwardVocabularyUISchema())


class RDMPersonOrOrganizationUISchema(ma.Schema):
    class Meta:
        unknown = ma.INCLUDE

    name = ma.fields.String()

    type = ma.fields.String()

    given_name = ma.fields.String()

    family_name = ma.fields.String()

    identifiers = ma.fields.List(ma.fields.Nested(RDMIdentifierWithSchemaUISchema()))


class RDMAffiliationVocabularyUISchema(DictOnlySchema):
    class Meta:
        unknown = ma.INCLUDE

    _id = ma.fields.String(data_key="id", attribute="id")

    _version = ma.fields.String(data_key="@v", attribute="@v")

    name = VocabularyI18nStrUIField()

class RDMCreatorsUISchema(ma.Schema):
    """Funding ui schema."""
    class Meta:
        unknown = ma.RAISE

    role = ma.fields.Nested(lambda: RDMRoleVocabularyUISchema())

    affiliations = ma.fields.List(ma.fields.Nested(lambda: RDMAffiliationVocabularyUISchema()))

    person_or_org = ma.fields.Nested(RDMPersonOrOrganizationUISchema())
